@@ -32,6 +32,19 @@ else:
 PY39 = (3, 9) <= sys.version_info
 
 
+def clamp(value, mn, mx):
+    """Clamp the value to the given minimum and maximum."""
+
+    if mn is not None and mx is not None:
+        return max(min(value, mx), mn)
+    elif mn is not None:
+        return max(value, mn)
+    elif mx is not None:
+        return min(value, mx)
+    else:
+        return value
+
+
 def is_win():  # pragma: no cover
     """Is Windows."""
 
@@ -139,7 +152,7 @@ def parse_url(url):
         is_absolute = True
     elif RE_WIN_DRIVE_LETTER.match(scheme):
         # c:/path
-        path = '/%s:%s' % (scheme, path.replace('\\', '/'))
+        path = '/{}:{}'.format(scheme, path.replace('\\', '/'))
         scheme = 'file'
         netloc = ''
         is_absolute = True
