@@ -108,9 +108,9 @@ class TestSnippets(util.MdCase):
                 ---8<--- "b.txt"
             ''',
             R'''
-            <p>Snippet
-            Snippet
-            ---8&lt;--- "b.txt"</p>
+            <p>Snippet</p>
+            <p>Snippet</p>
+            <p>---8&lt;--- "b.txt"</p>
             <ul>
             <li>
             <p>Testing indentation</p>
@@ -236,6 +236,131 @@ class TestSnippets(util.MdCase):
             True
         )
 
+    def test_start_multi(self):
+        """Test multiple line specifiers."""
+
+        self.check_markdown(
+            R'''
+            ---8<--- "lines.txt:1:2,8:9"
+            ''',
+            '''
+            <p>This is a multi-line
+            snippet.
+            This is the end of the file.
+            There is no more.</p>
+            ''',
+            True
+        )
+
+    def test_start_multi_no_end(self):
+        """Test multiple line specifiers but the last has no end."""
+
+        self.check_markdown(
+            R'''
+            ---8<--- "lines.txt:1:2,8"
+            ''',
+            '''
+            <p>This is a multi-line
+            snippet.
+            This is the end of the file.
+            There is no more.</p>
+            ''',
+            True
+        )
+
+    def test_start_multi_no_start(self):
+        """Test multiple line specifiers but the last has no start."""
+
+        self.check_markdown(
+            R'''
+            ---8<--- "lines.txt:1:2,:8"
+            ''',
+            '''
+            <p>This is a multi-line
+            snippet.
+            This is a multi-line
+            snippet.</p>
+            <p>Content resides on various lines.
+            If we use line specifiers,
+            we can select any number of lines we want.</p>
+            <p>This is the end of the file.</p>
+            ''',
+            True
+        )
+
+    def test_start_multi_hanging_comma(self):
+        """Test multiple line specifiers but there is a hanging comma."""
+
+        self.check_markdown(
+            R'''
+            ---8<--- "lines.txt:1:2,"
+            ''',
+            '''
+            ''',
+            True
+        )
+
+    def test_negative_range(self):
+        """Test negative indexing range."""
+
+        self.check_markdown(
+            R'''
+            ---8<--- "lines.txt:-3:-2"
+            ''',
+            '''
+            <p>This is the end of the file.
+            There is no more.</p>
+            ''',
+            True
+        )
+
+    def test_negative_single(self):
+        """Test negative indexing single line."""
+
+        self.check_markdown(
+            R'''
+            ---8<--- "lines.txt:-2:-2"
+            ''',
+            '''
+            <p>There is no more.</p>
+            ''',
+            True
+        )
+
+    def test_mixed_negative(self):
+        """Test negative indexing single line."""
+
+        self.check_markdown(
+            R'''
+            ---8<--- "lines.txt:8:-2"
+
+            ---8<--- "lines.txt:-3:9"
+            ''',
+            '''
+            <p>This is the end of the file.
+            There is no more.</p>
+            <p>This is the end of the file.
+            There is no more.</p>
+            ''',
+            True
+        )
+
+    def test_start_negative_multi(self):
+        """Test multiple line specifiers with negative indexes."""
+
+        self.check_markdown(
+            R'''
+            ---8<--- "lines.txt:1:2,-3:-2"
+            ''',
+            '''
+            <p>This is a multi-line
+            snippet.
+            This is the end of the file.
+            There is no more.</p>
+            ''',
+            True
+        )
+
     def test_end_line_inline(self):
         """Test ending line with inline syntax."""
 
@@ -401,6 +526,41 @@ class TestSnippets(util.MdCase):
             True
         )
 
+    def test_whole_file_with_sections(self):
+        """Test whole file with sections."""
+
+        self.check_markdown(
+            R'''
+            ```
+            -8<- "section_nested.txt"
+            ```
+            ''',
+            '''
+            <div class="highlight"><pre><span></span><code>div {
+                color: red;
+                background-color: white;
+                padding: 16px
+            }
+
+
+            div {
+                color: red;
+                /* --8&lt;-- [start: css-section4] */
+                background-color: white;
+                padding: 16px
+                /* --8&lt;-- [end: css-section4] */
+            }
+
+            div {
+                color: red;
+                background-color: white;
+                padding: 16px
+            }
+            </code></pre></div>
+            ''',
+            True
+        )
+
     def test_section_ignore_double_start_section(self):
         """Test nested sections."""
 
