@@ -609,6 +609,40 @@ class TestHighlightLines(util.MdCase):
             True
         )
 
+    def test_nonword_boundary_language(self):
+        """Test language with non-word boundary."""
+
+        self.check_markdown(
+            """
+            ```c++ hl_lines="1"
+            #include <iostream>
+            ```
+            """,
+            """
+            <div class="highlight"><pre><span></span><code><span class="hll"><span class="cp">#include</span><span class="w"> </span><span class="cpf">&lt;iostream&gt;</span>
+            </span></code></pre></div>
+            """,  # noqa: E501
+            True
+        )
+
+    def test_omitted_language(self):
+        """Test when language is omitted."""
+
+        self.check_markdown(
+            """
+            ```hl_lines="1"
+            some
+            code
+            ```
+            """,
+            """
+            <div class="highlight"><pre><span></span><code><span class="hll">some
+            </span>code
+            </code></pre></div>
+            """,
+            True
+        )
+
 
 class TestSuperFencesClassesIds(util.MdCase):
     """Test classes and ids without attribute lists."""
@@ -664,6 +698,33 @@ class TestSuperFencesClassesIds(util.MdCase):
             True
         )
 
+    def test_attrs_alternate_form(self):
+        """Test attributes with new alternate form."""
+
+        self.check_markdown(
+            r'''
+            ```python {.test .class #class}
+            import test
+            ```
+            ''',
+            r'''
+            <div id="class" class="test class highlight"><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div>
+            ''',  # noqa: E501
+            True
+        )
+
+    def test_issue_2479(self):
+        """Test issue #2479."""
+
+        self.check_markdown(
+            """```test_test_test_test_test_test_test_test``` test test.""",
+            """
+            <p><code>test_test_test_test_test_test_test_test</code> test test.</p>
+            """,
+            True
+        )
+
 
 class TestSuperFencesClassesIdsAttrList(util.MdCase):
     """Test fence ids and classes with attribute lists."""
@@ -767,6 +828,22 @@ class TestSuperFencesClassesIdsAttrList(util.MdCase):
             True
         )
 
+    def test_attrs_alternate_form(self):
+        """Test attributes with new alternate form."""
+
+        self.check_markdown(
+            r'''
+            ```python {.test .class #id data-attr="test" linenums="1"}
+            import test
+            ```
+            ''',
+            r'''
+            <div id="id" class="test class highlight" data-attr="test"><table class="highlighttable"><tr><td class="linenos"><div class="linenodiv"><pre><span></span><span class="normal">1</span></pre></div></td><td class="code"><div><pre><span></span><code><span class="kn">import</span> <span class="nn">test</span>
+            </code></pre></div></td></tr></table></div>
+            ''',  # noqa: E501
+            True
+        )
+
 
 class TestSuperFencesClassesIdsAttrListNoPygments(util.MdCase):
     """Test fence ids and classes with attribute lists and with no Pygments."""
@@ -929,7 +1006,7 @@ class TestSuperFencesBad(util.MdCase):
 class TestSuperFencesCustom(util.MdCase):
     """Test custom validator and format."""
 
-    extension = ['pymdownx.superfences']
+    extension = ['pymdownx.superfences', 'attr_list']
     extension_configs = {
         'pymdownx.superfences': {
             'custom_fences': [
@@ -1026,6 +1103,21 @@ class TestSuperFencesCustom(util.MdCase):
             True
         )
 
+    def test_custom_options_attr_list(self):
+        """Test option with correct value."""
+
+        self.check_markdown(
+            r'''
+            ```test {opt="A"}
+            test
+            ```
+            ''',
+            r'''
+            <div lang="test" class_name="class-test", option="A">test</div>
+            ''',
+            True
+        )
+
 
 class TestSuperFencesCustomException(util.MdCase):
     """Test custom validator and format."""
